pub fn parse_model(source: &str) -> Parsed<'_>Expand description
Parses source into the data model and validates it.
With a syntax error: no model, and every syntax error the parser could
recover to. Otherwise: the model, and every data-model error. Spans are
byte offsets into source.