Analysis

Struct Analysis 

#[non_exhaustive]
pub struct Analysis<'m> { pub externals: Vec<Name<'m>>, pub locals: Vec<Name<'m>>, pub markup: Vec<Name<'m>>, pub functions: Vec<Name<'m>>, }
What analyze found.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
externals: Vec<Name<'m>>

External variables — every variable the caller must supply: the variables of .input declarations and every variable referenced where no .local of that name is in scope (including variables used only in options, selectors or markup options). Unique under NFC, in ascending bytewise order of the NFC form: the manifest’s slot order.

locals: Vec<Name<'m>>

Local variables (.local declarations), in declaration order, unique under NFC.

markup: Vec<Name<'m>>

Markup names, unique under NFC, ascending by NFC form.

functions: Vec<Name<'m>>

Function identifiers (number, ns:fn), unique under NFC, ascending by NFC form.